AdMoneyInfoBean class

Constructors

AdMoneyInfoBean({required String adUnitId, required double revenue, required String networkName, required String revenuePrecision})

Properties

adUnitId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
networkName String
getter/setter pair
revenue double
getter/setter pair
revenuePrecision String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited